#!/usr/bin/env python3
# -*- coding: utf-8 -*-
# Copyright (C) 2021 tribe29 GmbH - License: GNU General Public License v2
# This file is part of Checkmk (https://checkmk.com). It is subject to the terms and
# conditions defined in the file COPYING, which is part of this source code package.

from cmk.gui.i18n import _
from cmk.gui.plugins.metrics import (
    metric_info,
    graph_info,
)

# rki_covid_weekIncidence=119.859135
#
# rki_covid_population=485570
# rki_covid_cases=18479
# rki_covid_recovered=16619
# rki_covid_deaths=649
#
# rki_covid_casesPer100k=3805.630496
#
# rki_covid_casesPerWeek=582
# rki_covid_deathsPerWeek=1
#
# rki_covid_delta_cases=171
# rki_covid_delta_deaths=3
# rki_covid_delta_recovered=83
# 

metric_info["rki_covid_weekIncidence"] = {
        "title": _("Week Incidence"),
        "unit": "count",
        "color": "42/a",
        }

metric_info["rki_covid_population"] = {
        "title": _("Population"),
        "unit": "count",
        "color": "51/a",
        }

metric_info["rki_covid_cases"] = {
        "title": _("Cases"),
        "unit": "count",
        "color": "13/a",
        }

metric_info["rki_covid_recovered"] = {
        "title": _("Recovered"),
        "unit": "count",
        "color": "31/a",
        }

metric_info["rki_covid_deaths"] = {
        "title": _("Deaths"),
        "unit": "count",
        "color": "14/a",
        }

metric_info["rki_covid_casesPer100k"] = {
        "title": _("Count per 100k"),
        "unit": "count",
        "color": "14/a",
        }

metric_info["rki_covid_casesPerWeek"] = {
        "title": _("Cases per Week"),
        "unit": "count",
        "color": "13/a",
        }

metric_info["rki_covid_deathsPerWeek"] = {
        "title": _("Deaths per Week"),
        "unit": "count",
        "color": "14/a",
        }

metric_info["rki_covid_delta_cases"] = {
        "title": _("Delta Cases"),
        "unit": "count",
        "color": "13/a",
        }

metric_info["rki_covid_delta_deaths"] = {
        "title": _("Delta Deaths"),
        "unit": "count",
        "color": "14/a",
        }

metric_info["rki_covid_delta_recovered"] = {
        "title": _("Delta Recovered"),
        "unit": "count",
        "color": "31/a",
        }

metric_info["rki_covid_r_value"] = {
        "title": _("R Value"),
        "unit": "count",
        "color": "42/a",
        }

graph_info["rki_covid_weekIncidence"] = {
    "title": "Week Incidence",
    "metrics": [
        ("rki_covid_weekIncidence", "line"),
    ],
    "scalars": [
        "rki_covid_weekIncidence:warn",
        "rki_covid_weekIncidence:crit",
    ],
    'range': (0, 'rki_covid_casesPer100k:max'),
}

graph_info["occurrences"] = {
    "title": "Occurrences",
    "metrics": [
        ("rki_covid_population", "line"),
        ("rki_covid_deaths", "area"),
        ("rki_covid_cases", "stack"),
        ("rki_covid_recovered", "stack"),
    ],
}

graph_info["rki_covid_casesPer100k"] = {
    "title": "Count per 100k",
    "metrics": [
        ("rki_covid_casesPer100k", "line"),
    ],
    'range': (0, 'rki_covid_casesPer100k:max'),
}

graph_info["weekly"] = {
    "title": "Weekly",
    "metrics": [
        ("rki_covid_deathsPerWeek", "area"),
        ("rki_covid_casesPerWeek", "stack"),
    ],
}

graph_info["delta"] = {
    "title": "Delta",
    "metrics": [
        ("rki_covid_delta_deaths", "area"),
        ("rki_covid_delta_cases", "stack"),
        ("rki_covid_delta_recovered", "stack"),
    ],
    "range": ("2,rki_covid_delta_recovered.min,*", "2,rki_covid_delta_recovered.max"),

}

graph_info["rki_covid_r_value"] = {
    "title": "R Value",
    "metrics": [
        ("rki_covid_r_value", "line"),
    ],
    "scalars": [
        "1",
    ],
    'range': (0, 'rki_covid_r_value:max'),
}

